const {Semester} = require("./Semester")

const ApplicationFormStatus = {
  Incomplete: {value: "@incomplete"},
  Expired: {value: "@expired"},
  Future: {value: "@future"},
  Active: {value: "@active"},

  GetStatus: GetApplicationFormStatus
}

function GetApplicationFormStatus(form) {
  if(!form) {
    return ""
  }

  if((!form.willingToTutor || !form.nativeLanguage) &&
      (!form.willingToLearn || !form.foreignLanguage)) 
  {
    return ApplicationFormStatus.Incomplete.value
  }
  if(!form.allowUndergrad && !form.allowGrad &&
      !form.allowAlumni && !form.allowEmployee &&
      !form.allowAnyone) 
  {
    return ApplicationFormStatus.Incomplete.value
  }
  if(!form.matchSemester || !form.matchYear) {
    return ApplicationFormStatus.Incomplete.value
  }

  const d = new Date()
  const month = d.getMonth()+1
  const year = d.getFullYear()

  if(form.matchYear < year) {
    return ApplicationFormStatus.Expired.value
  } else if(form.matchYear > year) {
    return ApplicationFormStatus.Future.value
  } else {
    if(month < Semester.BeginMonth(form.matchSemester)) {
      return ApplicationFormStatus.Future.value
    } else if(month > Semester.EndMonth(form.matchSemester)) {
      return ApplicationFormStatus.Expired.value
    } else {
      return ApplicationFormStatus.Active.value
    }
  }
}



module.exports = {
  ApplicationFormStatus,
}